# Generated by Django 3.2.7 on 2021-09-24 12:08

import uuid

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("visitors", "0005_visitorlog_status_code"),
    ]

    operations = [
        migrations.AlterField(
            model_name="visitor",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4, unique=True),
        ),
    ]
